==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/BridgeMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.BridgeSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeSetImpl;
import io.ciera.tool.sql.ooaofooa.message.BridgeMessage;
import io.ciera.tool.sql.ooaofooa.message.BridgeMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.SynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.List;


public class BridgeMessageSetImpl extends InstanceSet<BridgeMessageSet,BridgeMessage> implements BridgeMessageSet {

    // attributes
    @Override
    public void setBrg_ID( UniqueId ref_Brg_ID ) throws XtumlException {
        for ( BridgeMessage bridgemessage : this ) bridgemessage.setBrg_ID( ref_Brg_ID );
    }
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( BridgeMessage bridgemessage : this ) bridgemessage.setMsg_ID( ref_Msg_ID );
    }


    // selections
    @Override
    public BridgeSet R1012_is_invocation_of_Bridge() throws XtumlException {
        BridgeSet bridgeset = new BridgeSetImpl();
        for ( BridgeMessage bridgemessage : this ) bridgeset.add( bridgemessage.R1012_is_invocation_of_Bridge() );
        return bridgeset;
    }
    @Override
    public SynchronousMessageSet R1020_is_a_SynchronousMessage() throws XtumlException {
        SynchronousMessageSet synchronousmessageset = new SynchronousMessageSetImpl();
        for ( BridgeMessage bridgemessage : this ) synchronousmessageset.add( bridgemessage.R1020_is_a_SynchronousMessage() );
        return synchronousmessageset;
    }


    @Override
    public BridgeMessage nullElement() {
        return BridgeMessageImpl.EMPTY_BRIDGEMESSAGE;
    }

    @Override
    public BridgeMessageSet emptySet() {
      return new BridgeMessageSetImpl();
    }

    @Override
    public BridgeMessageSet value() {
        return this;
    }

    @Override
    public List<BridgeMessage> elements() {
        return Arrays.asList(toArray(new BridgeMessage[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/BridgeMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.BridgeSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeSetImpl;
import io.ciera.tool.sql.ooaofooa.message.BridgeMessage;
import io.ciera.tool.sql.ooaofooa.message.BridgeMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.SynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class BridgeMessageSetImpl extends InstanceSet<BridgeMessageSet,BridgeMessage> implements BridgeMessageSet {

    public BridgeMessageSetImpl() {
    }

    public BridgeMessageSetImpl(Comparator<? super BridgeMessage> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( BridgeMessage bridgemessage : this ) bridgemessage.setMsg_ID( ref_Msg_ID );
    }
    @Override
    public void setBrg_ID( UniqueId ref_Brg_ID ) throws XtumlException {
        for ( BridgeMessage bridgemessage : this ) bridgemessage.setBrg_ID( ref_Brg_ID );
    }


    // selections
    @Override
    public BridgeSet R1012_is_invocation_of_Bridge() throws XtumlException {
        BridgeSet bridgeset = new BridgeSetImpl();
        for ( BridgeMessage bridgemessage : this ) bridgeset.add( bridgemessage.R1012_is_invocation_of_Bridge() );
        return bridgeset;
    }
    @Override
    public SynchronousMessageSet R1020_is_a_SynchronousMessage() throws XtumlException {
        SynchronousMessageSet synchronousmessageset = new SynchronousMessageSetImpl();
        for ( BridgeMessage bridgemessage : this ) synchronousmessageset.add( bridgemessage.R1020_is_a_SynchronousMessage() );
        return synchronousmessageset;
    }


    @Override
    public BridgeMessage nullElement() {
        return BridgeMessageImpl.EMPTY_BRIDGEMESSAGE;
    }

    @Override
    public BridgeMessageSet emptySet() {
      return new BridgeMessageSetImpl();
    }

    @Override
    public BridgeMessageSet emptySet(Comparator<? super BridgeMessage> comp) {
      return new BridgeMessageSetImpl(comp);
    }

    @Override
    public BridgeMessageSet value() {
        return this;
    }

    @Override
    public List<BridgeMessage> elements() {
        return Arrays.asList(toArray(new BridgeMessage[0]));
    }

}
